@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "xmltokf" "0.2.3"
+(define-package "xmltokf" "20250126.656"
   "Functional wrappers around xmltok."
   '((emacs "25.1"))
   :url "https://github.com/paddymcall/xmltokf.el"
